/*Grid*/
.ui-jqgrid {
	position: relative;
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
	-ms-touch-action: none;
	touch-action: none;
}
.ui-jqgrid div {
	line-height: normal;
}
.ui-jqgrid table {
	border-collapse: separate;
	border-spacing: 0;
	border-width: 0;
	border-style: none;
}
.ui-jqgrid table td {
	padding: 0;
}
.ui-jqgrid > .ui-jqgrid-view {
	position: relative;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	left: 0;
	top: 0;
	padding: 0;
	font-size: 11px;
}
.ui-jqgrid > .ui-jqgrid-view *,
.ui-jqgrid > .ui-jqgrid-view *:before,
.ui-jqgrid > .ui-jqgrid-view *:after {
	-webkit-box-sizing: inherit;
	-moz-box-sizing: inherit;
	box-sizing: inherit;
}

/* caption of grid and title of ui-jqdialog */
.ui-jqgrid .ui-jqgrid-titlebar,
.ui-jqdialog .ui-jqdialog-titlebar {
	padding: .3em .3em .3em .3em;
	position: relative;
	font-size: 12px;
	border-left: 0 none;
	border-right: 0 none;
	border-top: 0 none;
}
.ui-jqgrid .ui-jqgrid-caption {
	text-align: left;
}
.ui-jqgrid .ui-jqgrid-caption-rtl {
	text-align: right;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close ,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close {
	vertical-align: middle;
	text-align: center;
	text-decoration: none;
	position: absolute;
	top: 50%;
	width: 18px;
	margin: -10px 0 0 0;
	padding: 1px;
	height: 18px;
	cursor: pointer;
}
.ui-jqgrid  .ui-jqgrid-caption .ui-jqgrid-titlebar-close,
.ui-jqdialog  .ui-jqdialog-titlebar-ltr .ui-jqdialog-titlebar-close {
	right: 2px;
}
.ui-jqgrid  .ui-jqgrid-caption-rtl .ui-jqgrid-titlebar-close,
.ui-jqdialog  .ui-jqdialog-titlebar-rtl .ui-jqdialog-titlebar-close {
	left: 2px;
}
.ui-jqgrid  .ui-jqgrid-caption .ui-jqgrid-title,
.ui-jqdialog  .ui-jqdialog-titlebar-ltr .ui-jqdialog-title {
	position: relative;
	left: .1em;
}
.ui-jqgrid  .ui-jqgrid-caption-rtl .ui-jqgrid-title,
.ui-jqdialog  .ui-jqdialog-titlebar-rtl .ui-jqdialog-title {
	position: relative;
	right: .1em;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close span,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close span {
	vertical-align: middle;
	text-align: center;
	display: block;
	margin: 1px;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:hover,
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:focus,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:hover,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:focus {
	padding: 0;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:hover > span,
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:focus > span,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:hover > span,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:focus > span {
	margin: 1px 0 0 1px;
}

/* header*/
.ui-jqgrid > .ui-jqgrid-view > .ui-jqgrid-hdiv {
	position: relative;
	margin: 0;
	padding: 0;
	overflow: hidden;
	border-left: 0 none;
	border-top: 0 none;
	border-right: 0 none;
	height: auto;
}
.ui-jqgrid .ui-jqgrid-hbox {
	float: left;
	padding-right: 20px;
}
.ui-jqgrid .ui-jqgrid-htable {
	table-layout: fixed;
	margin: 0;
}
.ui-jqgrid .ui-jqgrid-htable th {
	height: auto;
	padding: 0 2px 0 2px;
}
.ui-jqgrid .ui-jqgrid-htable .ui-jqgrid-labels th div {
	overflow: hidden;
	position: relative;
	height: auto;
	margin: 2px 2px;
}
.ui-jqgrid-labels .ui-th-column-header,
.ui-jqgrid .ui-jqgrid-labels th.ui-th-column {
	overflow: hidden;
	white-space: nowrap;
	text-align: center;
}
.ui-jqgrid .ui-jqgrid-labels th.ui-th-column {
	border-top: 0 none;
	border-bottom: 0 none;
}
.ui-th-ltr,
.ui-jqgrid .ui-jqgrid-htable th.ui-th-ltr {
	border-left: 0 none;
}
.ui-th-rtl,
.ui-jqgrid .ui-jqgrid-htable th.ui-th-rtl {
	border-right: 0 none;
}
.ui-first-th-ltr {
	border-right: 1px solid;
}
.ui-first-th-rtl {
	border-left: 1px solid;
}
.ui-jqgrid .ui-th-div-ie {
	white-space: nowrap;
	zoom: 1;
	height: 17px;
}
.ui-jqgrid .ui-th-column > .jqgh_cbox {
	margin: 3px 0;
}
.ui-jqgrid .ui-th-column .cbox {
	margin: 0;
	vertical-align: middle;
}
.ui-jqgrid .ui-th-column .ui-th-div-ie > .cbox {
	margin-left: -1px;
	margin-right: -1px;
}
.ui-jqgrid .ui-jqgrid-labels > .ui-th-column > .ui-jqgrid-resize {
	height: 22px;
	width: .3em;
	position: relative;
	cursor: col-resize;
	-webkit-touch-callout: none;
	-khtml-user-select: none;
	-ms-user-select: none;
	-moz-user-select: -moz-none;
	-webkit-user-select: none;
	-o-user-select: none;
	user-select: none;
	display: inline;
	overflow: hidden;
}

.ui-jqgrid .ui-grid-ico-sort {
	overflow: hidden;
	position: absolute;
	display: inline;
}
.ui-grid-ico-sort {
	/* use pointer cursor over all visible icons. It can be important if
		viewsortcols: [true, "vertical", false] or viewsortcols: [true, "horizontal", false]
		mode are used. The viewsortcols[2] element means that sorting are made only on clicking
		on the sorting icon. So the class ui-jqgrid-sortable will be not added to the div of
		the column header. It informs the user that clicking on the text of the column header
		will do nothing. One still need to have the cursor over the icon which inform about sorting.
	*/
	cursor: pointer;
}
.ui-state-disabled.ui-grid-ico-sort {
	cursor: pointer !important;/*to overwrite .ui-state-disabled { cursor: default !important; } from jQuery UI */
}
.ui-jqgrid .s-ico {
	position: relative;
	width: .87em;
	height: 1.125em;
	display: inline-block;
	vertical-align: middle;
	margin: 0 .1em
}
.ui-jqgrid .s-ico > .ui-grid-ico-sort {
	display: block;
	position: relative;
}
.ui-jqgrid .s-ico > .ui-grid-ico-sort.ui-icon {
	width: 12px;
}
.ui-jqgrid .s-ico > .ui-icon-asc.ui-icon {
	top: -6px;
}
.ui-jqgrid .s-ico > .ui-icon-desc.ui-icon {
	top: -16px;
}
.ui-jqgrid .s-ico > .ui-icon-asc.ui-icon.ui-sort-ltr {
	margin-left: -3px;
}
.ui-jqgrid .s-ico > .ui-icon-desc.ui-icon.ui-sort-ltr {
	margin-left: -4px;
}
.ui-jqgrid .s-ico > .ui-icon-asc.ui-icon.ui-sort-rtl {
	margin-right: 0;
}
.ui-jqgrid .s-ico > .ui-icon-desc.ui-icon.ui-sort-rtl {
	margin-right: 1px;
}

.ui-jqgrid .ui-th-column > div {
	cursor: default;
}
.ui-jqgrid .ui-th-column > div.ui-jqgrid-sortable {
	cursor: pointer;
}
.ui-jqgrid .ui-jqgrid-hdiv .ui-search-toolbar {
	border-top-width: 1px;
	border-top-style: solid;
}
.ui-jqgrid .ui-jqgrid-hdiv .ui-search-toolbar .ui-th-column {
	border-top-width: 1px;
	border-top-style: solid;
}
.ui-jqgrid .ui-jqgrid-hdiv .ui-search-toolbar input {
	margin: 1px 0 0 0;
}
.ui-jqgrid .ui-jqgrid-hdiv .ui-search-toolbar select {
	margin: 1px 0 0 0;
}

/* body */ 
.ui-jqgrid .ui-jqgrid-bdiv {
	position: relative;
	margin: 0;
	padding: 0;
	overflow: auto;
	text-align: left;
}
.ui-jqgrid .ui-jqgrid-btable {
	table-layout: fixed;
	margin: 0;
	outline-style: none;
}
.ui-jqgrid tr.jqgrow,
.ui-jqgrid tr.jqgroup {
	outline-style: none;
}
.ui-jqgrid tr.jqgrow > td,
.ui-jqgrid tr.jqgroup > td,
.ui-jqgrid tr.jqfoot > td,
.ui-jqgrid tr.jqfoot > td,
.ui-jqgrid tr.ui-subgrid > td {
	overflow: hidden;
	white-space: pre;
	height: 22px;
	border-top: 0 none;
	border-bottom-width: 1px;
	border-bottom-color: inherit;
	border-bottom-style: solid;
}
.ui-jqgrid tr.jqgrow > td,
.ui-jqgrid tr.jqgroup > td,
.ui-jqgrid tr.jqfoot > td,
.ui-jqgrid tr.jqfoot > td {
	padding: 0 2px 0 2px;
}
.ui-jqgrid tr.ui-subgrid > td {
	padding: 0;
}
.ui-jqgrid tr.jqgfirstrow > td {
	padding: 0 2px 0 2px;
	border-left: 0 none;
	border-right: 1px solid;
}
.ui-jqgrid tr.jqgrow > td,
.ui-jqgrid tr.jqgroup > td,
.ui-jqgrid tr.jqfoot > td  {
	font-weight: normal;
}
.ui-jqgrid tr.jqfoot > td {
	font-weight: bold;
}
.ui-jqgrid .ui-jqgrid-bdiv tr.ui-row-ltr > td {
	text-align: left;
	border-left: 0 none;
	border-right-width: 1px;
	border-right-color: inherit;
	border-right-style: solid;
}
.ui-jqgrid .ui-jqgrid-bdiv tr.ui-row-rtl > td {
	text-align: right;
	border-right: 0 none;
	border-left-width: 1px;
	border-left-color: inherit;
	border-left-style: solid;
}
.ui-jqgrid .ui-jqgrid-btable td.jqgrid-rownum {
	padding: 0 2px 0 2px;
	margin: 0;
	border: 0 none;
}
.ui-jqgrid .ui-jqgrid-btable td.jqgrid-rownum {
	border-bottom-width: 1px;
	border-bottom-style: solid;
	border-bottom-color: inherit;
}
.ui-jqgrid .jqgrow > td.td_cbox {
	padding: 0;
	text-align: center;
	vertical-align: middle;
}
.ui-jqgrid .jqgrow > td.ui-sgcollapsed {
	text-align: center;
	vertical-align: middle;
}
.ui-jqgrid .jqgrow > td > .cbox {
	vertical-align: middle;
}
.ui-jqgrid > .ui-jqgrid-resize-mark,
body > .ui-jqgrid-resize-mark {
	width: 0;
	left: 0;
	cursor: col-resize;
	-webkit-touch-callout: none;
	-khtml-user-select: none;
	-ms-user-select: none;
	-moz-user-select: -moz-none;
	-webkit-user-select: none;
	-o-user-select: none;
	user-select: none;
	position: absolute;
	top: 0;
	/*height: 100px;*/
	overflow: hidden;
	display: none;
	border-left-width: 1px;
	border-right-width: 1px;
	z-index: 99999;
}

span.ui-jqgrid-cell-wrapper {
	margin: 0 !important;
	padding: 0 !important;
}

/* footer */
.ui-jqgrid > .ui-jqgrid-view > .ui-jqgrid-sdiv {
	position: relative;
	margin: 0;
	padding: 0;
	overflow: hidden;
	border-left: 0 none;
	border-top: 0 none;
	border-right: 0 none;
}
.ui-jqgrid .ui-jqgrid-ftable {
	table-layout: fixed;
	margin-bottom: 0;
}
.ui-jqgrid tr.footrow td {
	font-weight: bold;
	overflow: hidden;
	white-space: nowrap;
	height: 21px;
	padding: 0 2px 0 2px;
	border-top-width: 1px;
	border-top-color: inherit;
	border-top-style: solid;
	border-bottom-width: 1px;
	border-bottom-style: solid;
	border-bottom-color: inherit;
}
.ui-jqgrid tr.footrow-ltr td {
	text-align: left;
	border-left: 0 none;
	border-right-width: 1px;
	border-right-color: inherit;
	border-right-style: solid;
}
.ui-jqgrid tr.footrow-rtl td {
	text-align: right;
	border-left-width: 1px;
	border-left-color: inherit;
	border-left-style: solid;
	border-right: 0 none;
}

/* Pager*/
.ui-jqgrid > .ui-jqgrid-pager {
	border: 0 none;
	margin: 0;
	padding: 0;
	position: relative;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	height: auto;
	min-height: 22px;
	overflow: hidden;
	font-size: 11px;
}
.ui-jqgrid > .ui-jqgrid-pager *,
.ui-jqgrid > .ui-jqgrid-pager *:before,
.ui-jqgrid > .ui-jqgrid-pager *:after {
	-webkit-box-sizing: inherit;
	-moz-box-sizing: inherit;
	box-sizing: inherit;
}
.ui-jqgrid .ui-jqgrid-toppager .ui-pager-control,
.ui-jqgrid .ui-jqgrid-pager .ui-pager-control {
	position: relative;
	border-left: 0;
	border-bottom: 0;
	border-top: 0;
}
.ui-jqgrid .ui-pg-table {
	position: relative;
	padding: 0;
	width: auto;
	margin: 0;
}
.ui-jqgrid .ui-pg-table td {
	font-weight: normal;
	vertical-align: middle;
	padding: 1px;
}
.ui-jqgrid .ui-pager-control .ui-pg-button {
	display: inline-block;
	height: auto;
}
.ui-jqgrid .ui-pg-button span {
	display: block;
	margin: 1px;
	float: left;
}
.ui-jqgrid .ui-pg-table .ui-pg-input,
.ui-jqgrid .ui-pg-table .ui-pg-selbox {
	height: auto;
	width: auto;
	margin: 0;
	line-height: inherit;
}
.ui-jqgrid .ui-pg-table .ui-pg-selbox {
	display: block;
	padding: 1px;
}
.ui-jqgrid .ui-separator {
	height: 12px;
	border-left: 1px solid #ccc;
	border-right: 1px solid #ccc;
	margin: -1px;
	float: right;
}
.ui-jqgrid .ui-paging-info {
	font-weight: normal;
	height: auto;
	margin: 0 .2em 0 .2em;
	display: inline;
}
.ui-jqgrid .ui-jqgrid-pager .ui-pg-div {
	padding: 1px 0;
	float: left;
	position: relative;
}
.ui-jqgrid .ui-jqgrid-pager .ui-pg-button {
	cursor: pointer;
}
.ui-jqgrid .ui-jqgrid-pager .ui-pg-div  span.ui-icon {
	float: left;
	margin: 0 2px;
}
.ui-jqgrid td input,
.ui-jqgrid td select,
.ui-jqgrid td textarea {
	margin: 0;
}
.ui-jqgrid td textarea {
	width: auto;
	height: auto;
}
.ui-jqgrid > .ui-jqgrid-view > .ui-jqgrid-toppager {
	border-left: 0 none;
	border-right: 0 none;
	border-top: 0 none;
	margin: 0;
	padding: 0;
	position: relative;
	height: auto;
	min-height: 22px;
	overflow: hidden;
}
.ui-jqgrid .ui-jqgrid-toppager .ui-pg-div {
	padding: 1px 0;
	float: left;
	position: relative;
}
.ui-jqgrid .ui-jqgrid-toppager .ui-pg-button {
	cursor: pointer;
}
.ui-jqgrid .ui-jqgrid-toppager .ui-pg-div  span.ui-icon {
	float: left;
	margin: 0 2px;
}

/* navigator buttons */
.ui-jqgrid .ui-pg-table .ui-pg-button.ui-state-disabled:hover {
	margin: 1px;
	padding: 2px;
}
.ui-jqgrid .navtable .ui-pg-button.ui-state-disabled:hover {
	margin: 0;
	padding: 2px;
}
.ui-jqgrid .ui-pg-table .ui-pg-button:hover {
	font-weight: normal;
	padding: -1px;
	margin: 1px;
}
.ui-jqgrid .ui-pg-table .ui-pg-button.ui-state-disabled:hover > .ui-separator {
	margin: -1px 1px;
	padding: 0 0;
}
.ui-jqgrid .ui-pg-table .ui-pg-button {
	margin: 2px;
	vertical-align: middle;
}
.ui-jqgrid .navtable .ui-pg-div span.ui-pg-button-text,
.ui-jqgrid .navtable .ui-pg-div span.ui-pg-button-text {
	padding-left: 0.2em;
	padding-right: 0.2em;
}
.ui-jqgrid .ui-pg-div {
	text-align: center;
	vertical-align: middle;
	display: inline-block;
}
.ui-jqgrid .navtable .ui-pg-div > span.ui-pg-button-icon-over-text {
	margin-left: auto;
	margin-right: auto;
	float: none;
}

/*subgrid*/
.ui-jqgrid .ui-jqgrid-btable .jqgrow > .ui-sgcollapsed {
	text-align: center;
	vertical-align: middle;
}
.ui-jqgrid .ui-jqgrid-btable .ui-sgcollapsed span {
	display: inline-block;
}
.ui-jqgrid .ui-subgrid {
	margin: 0;
	padding: 0;
	width: 100%;
}
.ui-jqgrid .ui-subgrid table {
	table-layout: fixed;
}
.ui-jqgrid .ui-subgrid tr.ui-subtblcell td {
	height: 18px;
	border-top: 0 none;
	border-bottom-width: 1px;
	border-bottom-color: inherit;
	border-bottom-style: solid;
}
.ui-jqgrid .ui-th-subgrid {
	height: 20px;
}
.ui-jqgrid .ui-row-ltr.ui-subgrid > .subgrid-cell > span {
	float: right;
}
.ui-jqgrid .ui-row-rtl.ui-subgrid > .subgrid-cell > span {
	float: left;
}

/* loading */
.ui-jqgrid > .loading {
	position: absolute;
	top: 45%;
	left: 45%;
	width: auto;
	z-index: 101;
	padding: 6px;
	margin: 5px;
	text-align: center;
	font-weight: bold;
	display: none;
	border-width: 2px;
	font-size: 11px;
}
.ui-jqgrid .jqgrid-overlay {
	display: none;
	z-index: 100;
}
* .jqgrid-overlay iframe {
	position: absolute;
	top: 0;
	left: 0;
	z-index: -1;
}

/* toolbar */
.ui-jqgrid > .ui-jqgrid-view > .ui-userdata {
	border-left: 0 none;
	border-right: 0 none;
	height: 21px;
	overflow: hidden;
}

/*Modal Window */
.ui-jqgrid .ui-jqdialog {
	font-size: 11px;
}
.ui-jqdialog {
	display: none;
	width: 300px;
	position: absolute;
	padding: .2em;
	font-size: 11px;
	overflow: visible;
}
.ui-jqdialog-content,
.ui-jqdialog .ui-jqdialog-content {
	border: 0;
	padding: .3em .2em;
	background: none;
	height: auto;
}
.ui-jqdialog .ui-jqconfirm {
	padding: .4em 1em;
	border-width: 3px;
	position: absolute;
	bottom: 10px;
	right: 10px;
	overflow: visible;
	display: none;
	height: 80px;
	width: 220px;
	text-align: center;
}
.ui-jqgrid > .ui-resizable-se,
.ui-jqdialog > .ui-resizable-se {
	bottom: -3px;
	right: -3px;
}

/* Form edit */
.ui-jqdialog-content .FormGrid {
	margin: 0;
}
.ui-jqdialog-content .EditTable {
	width: 100%;
	margin-bottom: 0;
}
.ui-jqdialog-content .DelTable {
	width: 100%;
	margin-bottom: 0;
}
.EditTable td input,
.EditTable td select,
.EditTable td textarea {
	margin: 0;
}
.EditTable td textarea {
	width: auto;
	height: auto;
}
.ui-jqdialog-content td.EditButton {
	border-top: 0 none;
	border-left: 0 none;
	border-right: 0 none;
	padding: 5px 0;
}
.ui-jqdialog-content td.EditButton-ltr {
	text-align: right;
}
.ui-jqdialog-content td.EditButton-rtl {
	text-align: left;
}
.ui-jqdialog-content td.navButton {
	text-align: left;
	border-left: 0 none;
	border-top: 0 none;
	border-right: 0 none;
	padding: 5px 0;
}
.ui-jqdialog-content td.navButton-ltr {
	text-align: left;
}
.ui-jqdialog-content td.navButton-ltr > .fm-button {
	float: left;
}
.ui-jqdialog-content td.navButton-rtl {
	text-align: right;
}
.ui-jqdialog-content td.navButton-rtl > .fm-button {
	float: right;
}
.ui-jqdialog-content input.FormElement {
	padding: .3em;
}
.ui-jqdialog-content select.FormElement {
	padding: .3em;
}
.ui-jqdialog-content .data-line {
	padding-top: .1em;
	border: 0 none;
}
.ui-jqdialog-content .CaptionTD {
	vertical-align: middle;
	border: 0 none;
	padding: 2px;
	white-space: nowrap;
}
.ui-jqdialog-content .DataTD {
	padding: 2px;
	border: 0 none;
	vertical-align: top;
}
.ui-jqdialog-content .form-view-data {
	white-space: pre;
}
.ui-jqdialog .fm-button {
	display: inline-block;
	padding: .4em .5em;
	text-decoration: none;
	cursor: pointer;
	position: relative;
	text-align: center;
	zoom: 1;
}
.ui-jqdialog .fm-button.ui-state-disabled:hover {
	padding: .4em .5em;
}
.ui-jqdialog .fm-button > span {
	display: inline-block;
	vertical-align: middle;
}
.ui-jqdialog .fm-button .fm-button-text {
	padding: 0 .2em;
}
.ui-jqdialog .EditButton-ltr .fm-button-icon-left .fm-button-icon {
    margin-right: .2em;
}
.ui-jqdialog .EditButton-ltr .fm-button-icon-right .fm-button-icon {
    margin-left: .2em;
}
.ui-jqdialog .EditButton-rtl .fm-button-icon-right .fm-button-icon {
    margin-right: .2em;
}
.ui-jqdialog .EditButton-rtl .fm-button-icon-left .fm-button-icon {
    margin-left: .2em;
}

/*.ui-jqgrid .edit-cell {}*/
.ui-jqgrid .selected-row,
.ui-jqgrid .selected-row td {
	font-style: normal;
	border-left: 0 none;
}

/* inline edit actions button*/
.ui-jqgrid  .jqgrow .ui-jqgrid-actions {
	display: inline-block;
	vertical-align: middle;
	margin: 0;
}
.ui-jqgrid  .jqgrow  .ui-jqgrid-actions > .ui-pg-div.ui-state-hover {
	margin: -1px 0 -1px 0;
}
.jqgrow .ui-jqgrid-actions .ui-pg-div {
	cursor: pointer;
	float: left;
	margin: 0 1px;
}
/* Tree Grid */
.ui-jqgrid .tree-wrap {
	float: left;
	position: relative;
	height: 18px;
	white-space: nowrap;
	overflow: hidden;
}
.ui-jqgrid .tree-minus {
	position: absolute;
	height: 18px;
	width: 18px;
	overflow: hidden;
}
.ui-jqgrid .tree-plus {
	position: absolute;
	height: 18px;
	width: 18px;
	overflow: hidden;
}
.ui-jqgrid .tree-leaf {
	position: absolute;
	height: 18px;
	width: 18px;
	overflow: hidden;
}
.ui-jqgrid .treeclick {
	cursor: pointer;
}

/* modal dialog */
* iframe.jqm {
	position: absolute;
	top: 0;
	left: 0;
	z-index: -1;
}
.ui-jqgrid-dnd tr td {
	border-right-width: 1px;
	border-right-color: inherit;
	border-right-style: solid;
	height: 20px;
}

/* RTL Support */
.ui-jqgrid .ui-jqgrid-caption-rtl {
	text-align: right;
}
.ui-jqgrid .ui-jqgrid-hbox-rtl {
	float: right;
	padding-left: 20px;
}
.ui-jqgrid .ui-jqgrid-resize-ltr {
	float: right;
	margin: -2px -2px -2px 0;
}
.ui-jqgrid .ui-jqgrid-resize-rtl {
	float: left;
	margin: -2px 0 -1px -3px;
}
.ui-jqgrid .ui-sort-rtl {
	left: 0;
}
.ui-jqgrid .tree-wrap-ltr {
	float: left;
}
.ui-jqgrid .tree-wrap-rtl {
	float: right;
}
.ui-jqgrid .ui-ellipsis {
	-moz-text-overflow: ellipsis;
	text-overflow: ellipsis;
}

/* Toolbar Search Menu */
.ui-search-menu {
	position: absolute;
	padding: 2px 5px;
}
.ui-search-menu.ui-menu .ui-menu-item {
	list-style-image: none;
	padding-right: 0;
	padding-left: 0;
}
.ui-search-menu.ui-menu .ui-menu-item a {
	text-decoration: none;
	display: block;
}
.ui-search-menu.ui-menu .ui-menu-item a.g-menu-item:hover {
	margin: -1px;
	font-weight: normal;
}
.ui-jqgrid .ui-search-table {
	padding: 0;
	border: 0 none;
	height: 20px;
	width: 100%;
}
.ui-jqgrid .ui-search-table .ui-search-oper {
	width: 20px;
}
a.g-menu-item,
a.soptclass,
a.clearsearchclass {
	text-decoration: none;
	cursor: pointer;
}
.ui-jqgrid .ui-search-table .ui-search-input > input,
.ui-jqgrid .ui-search-table .ui-search-input > select {
	display: block;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
}
.ui-jqgrid > .ui-jqgrid-view input,
.ui-jqgrid > .ui-jqgrid-view select,
.ui-jqgrid > .ui-jqgrid-view textarea,
.ui-jqgrid > .ui-jqgrid-view button {
	font-size: 11px;
}

/* support of fontAwesome */
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close > span.fa {
	font-size: 16px;
	display: inline-block;
}
.ui-jqdialog .ui-jqdialog-titlebar-close > span.fa {
	margin-top: 4px;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:hover,
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:hover  {
	margin-top: -9px;
}
.ui-jqgrid-titlebar > .ui-jqgrid-titlebar-close:hover > span.fa {
	margin-top: 1px;
}
.ui-jqdialog-titlebar > .ui-jqdialog-titlebar-close:hover > span.fa {
	margin-top: 3px;
}
.ui-jqgrid .s-ico > .ui-grid-ico-sort.fa {
	width: .63em;
}
.ui-jqgrid .s-ico > .ui-icon-asc.fa {
	top: 0.07em;
}
.ui-jqgrid .s-ico > .ui-icon-desc.fa {
	top: -0.75em;
}
.ui-jqgrid .s-ico > .ui-icon-asc.fa.ui-sort-ltr,
.ui-jqgrid .s-ico > .ui-icon-desc.fa.ui-sort-ltr {
	left: 0;
}
.ui-jqgrid .s-ico > .ui-icon-asc.fa.ui-sort-rtl,
.ui-jqgrid .s-ico > .ui-icon-desc.fa.ui-sort-rtl {
	right: 0;
}
.ui-jqgrid .s-ico > .ui-state-disabled.fa {
	padding: 0;
}
.jqgrow .ui-pg-div > span.fa {
	font-weight: normal;
	font-size: 12px;
	vertical-align: baseline;
	background: none;
	border: 0 none;
}
.ui-subgrid > .subgrid-cell span.fa {
	font-weight: normal;
	font-size: 12px;
	text-indent: 0;
	background: none;
	border: 0 none;
	margin-bottom: 4px;
}
.jqgrow > .ui-sgcollapsed span.fa {
	font-weight: normal;
	font-size: 12px;
	text-indent: 0;
	background: none;
	border: 0 none;
	margin: 0;
}
.ui-jqgrid .ui-resizable-se.fa {
	-webkit-filter: alpha(opacity=40);
	-moz-filter: alpha(opacity=40);
	-o-filter: alpha(opacity=40);
	filter: alpha(opacity=40);
	-ms-opacity: 0.4;
	opacity: 0.4;
	background: none;
	border-style: none;
	right: -3px;
	font-weight: normal;
}

.ui-jqgrid-ltr .ui-resizable-se.fa {
	right: -3px;
	bottom: 0;
}
.ui-jqgrid-rtl .ui-resizable-se.fa {
	left: 0;
	bottom: 1px;
}

/* classes for jquery.contextmenu-ui.js plugin we included here */
.jqContextMenu .ui-menu .ui-menu-item a.ui-state-hover {
	font-weight: normal;
	margin: -1px;
}
.jqContextMenu .ui-menu .ui-menu-item.ui-state-hover {
	font-weight: normal;
	margin: -1px;
}
.jqContextMenu .ui-menu-icons > .ui-menu-item {
	font-size: 11px;
}
/* classes for jQuery.jqGrid.showHideColumnMenu.js plugin */
.ui-jqgrid-showHideColumnMenu .ui-menu-item:hover {
	font-weight: normal;
}
.ui-jqgrid-disablePointerEvents {
	pointer-events: none;
}